@@ -210,9 +210,7 @@ def phonon_bandplot(
             )
 
         else:
-            logging.info(
-                "No input data, using file {} " "to construct plot".format(from_json[0])
-            )
+            logging.info(f"No input data, using file {from_json[0]} to construct plot")
             with open(from_json[0]) as f:
                 bs = PhononBandStructureSymmLine.from_dict(json.load(f))
             from_json = from_json[1:]
@@ -381,7 +379,7 @@ def _bs_from_filename(
                 logging.error(f"\n {msg}")
                 sys.exit()
 
-            dim = sposcar.structure.lattice.matrix * poscar.structure.lattice.inv_matrix
+            dim = sposcar.structure.lattice.matrix @ poscar.structure.lattice.inv_matrix
 
             # round due to numerical noise error
             dim = np.around(dim, 5)
@@ -406,7 +404,6 @@ def _bs_from_filename(
             filename,
             poscar.structure,
             dim,
-            symprec=symprec,
             primitive_matrix=primitive_axis,
             factor=factors[units.lower()],
             symmetrise=True,
@@ -423,9 +420,7 @@ def _bs_from_filename(
 
         cell_file = ".".join(filename.split(".")[:-1] + ["cell"])
         if isfile(cell_file):
-            logging.info(
-                "Found .cell file, reading x-axis labels from " "{}".format(cell_file)
-            )
+            logging.info(f"Found .cell file, reading x-axis labels from {cell_file}")
             castep_phonon.set_labels_from_file(cell_file)
         else:
             logging.warning("No .cell file found, cannot read x-axis labels.")
@@ -458,9 +453,11 @@ def _bs_from_filename(
     # phonon.set_partial_DOS()
 
     if ".yaml" not in filename:
-        phonon.set_band_structure(kpoints, is_eigenvectors=eigenvectors, labels=labels)
+        phonon.run_band_structure(
+            kpoints, with_eigenvectors=eigenvectors, labels=labels
+        )
         yaml_file = "sumo_band.yaml"
-        phonon._band_structure.write_yaml(filename=yaml_file)
+        phonon.band_structure.write_yaml(filename=yaml_file)
 
     bs = get_ph_bs_symm_line(yaml_file, has_nac=False, labels_dict=kpath.kpoints)
     return bs, phonon
@@ -471,12 +468,10 @@ def _get_parser():
         description="""
     phonon-bandplot is a script to produce publication ready phonon band
     structure diagrams""",
-        epilog="""
-    Author: {}
-    Version: {}
-    Last updated: {}""".format(
-            __author__, __version__, __date__
-        ),
+        epilog=f"""
+    Author: {__author__}
+    Version: {__version__}
+    Last updated: {__date__}""",
     )
 
     parser.add_argument(
