@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Scanlon Materials Theory Group
 # Distributed under the terms of the MIT License.
 
@@ -16,6 +15,7 @@ from pymatgen.electronic_structure.core import Spin
 from sumo.electronic_structure.dos import sort_orbitals
 from sumo.plotting import (
     colour_cache,
+    draw_themed_line,
     pretty_plot,
     pretty_subplot,
     styled_plot,
@@ -31,7 +31,7 @@ except ImportError:
 empty_space = 1.05
 
 
-class SDOSPlotter(object):
+class SDOSPlotter:
     """Class for plotting density of states data.
 
     This class should be initialised with the total and partial density
@@ -71,6 +71,7 @@ class SDOSPlotter(object):
         legend_cutoff=3,
         subplot=False,
         zero_to_efermi=True,
+        zero_energy=None,
         cache=None,
         spin=None,
     ):
@@ -104,6 +105,9 @@ class SDOSPlotter(object):
                 each element on separate subplots. Defaults to ``False``.
             zero_to_efermi (:obj:`bool`, optional): Normalise the plot such
                 that the Fermi level is set as 0 eV.
+            zero_energy (:obj:`float`, optional): If provided, this value is
+                used as the 0 eV reference. Otherwise, behaviour depends on
+                zero_to_efermi.
             cache (:obj:`dict`, optional): Cache object tracking how colours
                 have been assigned to orbitals. The format is the same as the
                 "colours" dict. This defaults to the module-level
@@ -147,10 +151,20 @@ class SDOSPlotter(object):
         if cache is None:
             cache = colour_cache
 
-        # mask needed to prevent unwanted data in pdf and for finding y limit
         dos = self._dos
         pdos = self._pdos
-        eners = dos.energies - dos.efermi if zero_to_efermi else dos.energies
+
+        if zero_energy is None:
+            energy_shift = -dos.efermi if zero_to_efermi else 0.0
+        elif zero_to_efermi:
+            raise ValueError(
+                "Cannot use zero_energy and " "zero_to_efermi simultaneously."
+            )
+        else:
+            energy_shift = -zero_energy
+        eners = dos.energies + energy_shift
+
+        # mask needed to prevent unwanted data in pdf and for finding y limit
         mask = (eners >= xmin - 0.05) & (eners <= xmax + 0.05)
         plot_data = {"mask": mask, "energies": eners}
         spins = dos.densities.keys()
@@ -162,7 +176,7 @@ class SDOSPlotter(object):
 
         # Visibility cutoff based on scale of total plot even if it is hidden
         try:
-            dmax = max([max(d[mask]) for d in dos.densities.values()])
+            dmax = max(max(d[mask]) for d in dos.densities.values())
         except ValueError:
             dmax = 0
 
@@ -197,9 +211,9 @@ class SDOSPlotter(object):
         for el, el_pdos in pdos.items():
             el_lines = []
             for orb in sort_orbitals(el_pdos):
-                dmax = max([max(d[mask]) for d in el_pdos[orb].densities.values()])
+                dmax = max(max(d[mask]) for d in el_pdos[orb].densities.values())
                 ymax = dmax if dmax > ymax else ymax
-                label = None if dmax < cutoff else "{} ({})".format(el, orb)
+                label = None if dmax < cutoff else f"{el} ({orb})"
                 colour, cache = get_cached_colour(el, orb, colours, cache=cache)
                 el_lines.append(
                     {
@@ -237,6 +251,8 @@ class SDOSPlotter(object):
         xlabel="Energy (eV)",
         ylabel="Arb. units",
         zero_to_efermi=True,
+        zero_line=False,
+        zero_energy=None,
         dpi=400,
         fonts=None,
         plt=None,
@@ -282,6 +298,10 @@ class SDOSPlotter(object):
             ylabel (:obj:`str`, optional): Label/units for y-axis (i.e. DOS)
             zero_to_efermi (:obj:`bool`, optional): Normalise the plot such
                 that the Fermi level is set as 0 eV.
+            zero_line (:obj:`bool`, optional): Draw a line at 0 eV.
+            zero_energy (:obj:`float`, optional): If provided, this value is
+                used as the 0 eV reference. Otherwise, behaviour depends on
+                zero_to_efermi.
             dpi (:obj:`int`, optional): The dots-per-inch (pixel density) for
                 the image.
             fonts (:obj:`list`, optional): Fonts to use in the plot. Can be a
@@ -295,9 +315,9 @@ class SDOSPlotter(object):
             no_base_style (:obj:`bool`, optional): Prevent use of sumo base
                 style. This can make alternative styles behave more
                 predictably.
-            spin (:obj:`Spin`, optional): Plot a spin-polarised density of states,
-            "up" or "1" for spin up only, "down" or "-1" for spin down only.
-            Defaults to ``None``.
+            spin (:obj:`Spin`, optional): Plot a spin-polarised density of
+                states, "up" or "1" for spin up only, "down" or "-1" for spin
+                down only.  Defaults to ``None``.
 
         Returns:
             :obj:`matplotlib.pyplot`: The density of states plot.
@@ -311,6 +331,7 @@ class SDOSPlotter(object):
             legend_cutoff=legend_cutoff,
             subplot=subplot,
             zero_to_efermi=zero_to_efermi,
+            zero_energy=zero_energy,
             spin=spin,
         )
 
@@ -358,6 +379,10 @@ class SDOSPlotter(object):
                 )
                 ax.plot(energies, densities, label=label, color=line["colour"])
 
+            if zero_line:
+                draw_themed_line(0, ax, orientation="vertical")
+
+            ax.set_ylim(plot_data["ymin"], plot_data["ymax"])
             ax.set_xlim(xmin, xmax)
             if len(spins) == 1:
                 ax.set_ylim(0, plot_data["ymax"])
